@@ -59,7 +59,7 @@ class HttpCycle(HttpCycleBase[Request, Response]):
 
         return {
             'type': 'http',
-            'asgi': {'version': '3.0'},
+            'asgi': {'version': '3.0', 'spec_version': '2.2'},
             'http_version': '1.1',
             'method': method,
             'scheme': 'http',
@@ -68,16 +68,19 @@ class HttpCycle(HttpCycleBase[Request, Response]):
             'headers': headers,
             'server': None,
             'client': None,
+            'state': self.state,
         }
 
     async def receive(self) -> Message:
         event = self.request['event']
         body = event.get('body', '')
-
-        if event.get('isBase64Encoded', False):
-            body = b64decode(body)
+        if body is None:
+            body = b''
         else:
-            body = body.encode()
+            if event.get('isBase64Encoded', False):
+                body = b64decode(body)
+            else:
+                body = body.encode()
         return {
             'type': 'http.request',
             'body': body,
